==> glade-3.15.1.tar.xz: glade-3.15.1/gladeui/gladeui-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __GLADEUI_ENUM_TYPES_H__
#define __GLADEUI_ENUM_TYPES_H__

#include <glib-object.h>
#include <gladeui/glade.h>

G_BEGIN_DECLS

/* enumerations from "glade-cursor.h" */
GType glade_cursor_type_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_CURSOR_TYPE (glade_cursor_type_get_type ())

/* enumerations from "glade-editable.h" */
GType glade_editor_page_type_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_EDITOR_PAGE_TYPE (glade_editor_page_type_get_type ())

/* enumerations from "glade-palette.h" */
GType glade_item_appearance_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_ITEM_APPEARANCE (glade_item_appearance_get_type ())

/* enumerations from "glade-project.h" */
GType glade_pointer_mode_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_POINTER_MODE (glade_pointer_mode_get_type ())
GType glade_support_mask_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_SUPPORT_MASK (glade_support_mask_get_type ())
GType glade_project_model_columns_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_PROJECT_MODEL_COLUMNS (glade_project_model_columns_get_type ())
GType glade_verify_flags_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_VERIFY_FLAGS (glade_verify_flags_get_type ())

/* enumerations from "glade-property.h" */
GType glade_property_state_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_PROPERTY_STATE (glade_property_state_get_type ())

/* enumerations from "glade-signal-model.h" */
GType glade_signal_model_columns_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_SIGNAL_MODEL_COLUMNS (glade_signal_model_columns_get_type ())

/* enumerations from "glade-utils.h" */
GType glade_util_file_dialog_type_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_UTIL_FILE_DIALOG_TYPE (glade_util_file_dialog_type_get_type ())
GType glade_ui_message_type_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_UI_MESSAGE_TYPE (glade_ui_message_type_get_type ())

/* enumerations from "glade-widget-adaptor.h" */
GType glade_create_reason_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_CREATE_REASON (glade_create_reason_get_type ())
G_END_DECLS

#endif /* __GLADEUI_ENUM_TYPES_H__ */

/* Generated data ends here */

==> glade_3.18.3.orig.tar.xz: glade-3.18.3/gladeui/gladeui-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __GLADEUI_ENUM_TYPES_H__
#define __GLADEUI_ENUM_TYPES_H__

#include <glib-object.h>
#include <gladeui/glade.h>

G_BEGIN_DECLS

/* enumerations from "glade-cursor.h" */
GType glade_cursor_type_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_CURSOR_TYPE (glade_cursor_type_get_type ())

/* enumerations from "glade-debug.h" */
GType glade_debug_flag_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_DEBUG_FLAG (glade_debug_flag_get_type ())

/* enumerations from "glade-editable.h" */
GType glade_editor_page_type_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_EDITOR_PAGE_TYPE (glade_editor_page_type_get_type ())

/* enumerations from "glade-palette.h" */
GType glade_item_appearance_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_ITEM_APPEARANCE (glade_item_appearance_get_type ())

/* enumerations from "glade-project.h" */
GType glade_pointer_mode_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_POINTER_MODE (glade_pointer_mode_get_type ())
GType glade_support_mask_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_SUPPORT_MASK (glade_support_mask_get_type ())
GType glade_project_model_columns_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_PROJECT_MODEL_COLUMNS (glade_project_model_columns_get_type ())
GType glade_verify_flags_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_VERIFY_FLAGS (glade_verify_flags_get_type ())

/* enumerations from "glade-property.h" */
GType glade_property_state_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_PROPERTY_STATE (glade_property_state_get_type ())

/* enumerations from "glade-signal-model.h" */
GType glade_signal_model_columns_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_SIGNAL_MODEL_COLUMNS (glade_signal_model_columns_get_type ())

/* enumerations from "glade-utils.h" */
GType glade_util_file_dialog_type_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_UTIL_FILE_DIALOG_TYPE (glade_util_file_dialog_type_get_type ())
GType glade_ui_message_type_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_UI_MESSAGE_TYPE (glade_ui_message_type_get_type ())

/* enumerations from "glade-widget-adaptor.h" */
GType glade_create_reason_get_type (void) G_GNUC_CONST;
#define GLADE_TYPE_CREATE_REASON (glade_create_reason_get_type ())
G_END_DECLS

#endif /* __GLADEUI_ENUM_TYPES_H__ */

/* Generated data ends here */
